@@ -5,7 +5,6 @@ import time
 from typing import List
 
 import numpy as np
-import pandas as pd
 from rich.console import Console
 from rich.progress import Progress
 
@@ -188,28 +187,24 @@ class CSV_Edem_Batch:
         else:
             logger.info("Not exporting log mean information")
 
-        df = pd.DataFrame(data, columns=headers)
+        column_widths: List[int] = []
+        align: List[str] = []
 
-        # save data to excel and auto adjust columns width
-        writer = pd.ExcelWriter(
-            filename, engine="xlsxwriter", options={"strings_to_numbers": True}
+        column_widths.append(len(data[0, 0]) + 10)
+        align.append("left")
+
+        for i, header in enumerate(headers):
+            if i > 0:
+                column_widths.append(len(header))
+                align.append("right")
+
+        utils.saveDataToExcel(
+            filename,
+            data,
+            headers,
+            sheetname=sheetname,
+            column_widths=column_widths,
+            align=align,
         )
 
-        df.to_excel(writer, sheet_name=sheetname, index=False)  # send df to writer
-        worksheet = writer.sheets[sheetname]  # pull worksheet object
-        for idx, col in enumerate(df):  # loop through all columns
-            series = df[col]
-            max_len = (
-                max(
-                    (
-                        series.astype(str).map(len).max(),  # len of largest item
-                        len(str(series.name)),  # len of column name/header
-                    )
-                )
-                + 1
-            )  # adding a little extra space
-            worksheet.set_column(idx, idx, max_len)  # set column width
-        writer.save()
-
-        logger.info('Exported data to excel file: "{}"'.format(filename))
         return
